class Constants:
    base_url = "https://cdn-api.co-vin.in/api/v2"

    states_list_url = f"{base_url}/admin/location/states"
    districts_list_url = f"{base_url}/admin/location/districts"

    availability_by_pin_code_url = f"{base_url}/appointment/sessions/public/calendarByPin"
    availability_by_district_url = f"{base_url}/appointment/sessions/public/calendarByDistrict"

    DD_MM_YYYY = "%d-%m-%Y"



from datetime import datetime

from cowin_api.constants import Constants


def today() -> str:
    return datetime.now().strftime(Constants.DD_MM_YYYY)


def filter_centers_by_age_limit(centers: dict, min_age_limit: int):
    original_centers = centers.get('centers')
    filtered_centers = {'centers': []}
    for index, center in enumerate(original_centers):
        filtered_sessions = []
        for session in center.get('sessions'):
            if session.get('min_age_limit') == min_age_limit:
                filtered_sessions.append(session)
        if len(filtered_sessions) > 0:
            center['sessions'] = filtered_sessions
            filtered_centers['centers'].append(center)

    return filtered_centers



from typing import Union

import requests
from fake_useragent import UserAgent
from requests.exceptions import HTTPError


class BaseApi:

    def _call_api(self, url) -> Union[HTTPError, dict]:
        user_agent = UserAgent()
        headers = {'User-Agent': user_agent.random}
        response = requests.get(url, headers=headers)
        try:
            response.raise_for_status()
        except requests.exceptions.HTTPError as e:
            return e

        return response.json()



from cowin_api.base_api import BaseApi
from cowin_api.constants import Constants
from cowin_api.utils import today, filter_centers_by_age_limit


class CoWinAPI(BaseApi):

    def get_states(self):
        url = Constants.states_list_url
        return self._call_api(url)

    def get_districts(self, state_id: str):
        url = f"{Constants.districts_list_url}/{state_id}"
        return self._call_api(url)

    def get_availability_by_district(self, district_id: str, date: str = today(), min_age_limt: int = None):
        url = f"{Constants.availability_by_district_url}?district_id={district_id}&date={date}"
        return filter_centers_by_age_limit(self._call_api(url), min_age_limt) if min_age_limt else self._call_api(url)

    def get_availability_by_pincode(self, pin_code: str, date: str = today(), min_age_limt: int = None):
        url = f"{Constants.availability_by_pin_code_url}?pincode={pin_code}&date={date}"
        return filter_centers_by_age_limit(self._call_api(url), min_age_limt) if min_age_limt else self._call_api(url)



import pathlib

from setuptools import setup

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='cowin',
    version='0.0.4',
    description='Python wrapper for CoWin API',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url=' https://github.com/backtrackbaba/cowin',
    author='Saiprasad Balasubramanian',
    author_email='sai.cosmo@gmail.com',
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Environment :: Console',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
    ],
    keywords='cowin, covid, vaccine',
    packages=['cowin_api'],
    include_package_data=True,
    python_requires='>=3.6, <4',
    install_requires=[
        'fake-useragent==0.1.11',
        'pytest==6.2.3',
        'requests==2.25.1'
    ],
    project_urls={  # Optional
        'Bug Reports': 'https://github.com/backtrackbaba/cowin/issues',
        'Source': 'https://github.com/backtrackbaba/cowin',
    },
)
